@@ -1,5 +1,5 @@
 #' @title Check GDAL installation
-#' @description The function check that GDAL is installed and updated to
+#' @description The function checks that GDAL is installed and updated to
 #'  the minimum required version (2.1.2).
 #' @param abort Logical parameter: if TRUE (default), the function aborts
 #'  in case no GDAL installation is found; if FALSE, a warning is shown
@@ -22,17 +22,17 @@
 #'  if GDAL is missing and abort=FALSE (otherwise, the function stops).
 #'
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
+#' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
+#'  "sen2r": An R toolbox for automatically downloading and preprocessing 
+#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. DOI: 
+#'  \href{https://doi.org/10.1016/j.cageo.2020.104473}{10.1016/j.cageo.2020.104473}, 
+#'  URL: \url{http://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @importFrom jsonlite toJSON
 #' @export
 #' @examples
 #' \donttest{
-#'
-#' # Use function
 #' check_gdal()
-#'
-#' # Check GDAL was imported
-#' load_binpaths()$gdalinfo
 #' }
 
 check_gdal <- function(abort = TRUE, gdal_path = NULL, force = FALSE, full_scan = FALSE) {
@@ -43,6 +43,9 @@ check_gdal <- function(abort = TRUE, gdal_path = NULL, force = FALSE, full_scan
   # load the saved GDAL path, if exists
   binpaths <- load_binpaths()
   
+  # remove old GDAL paths, if present
+  binpaths$ogrinfo <- binpaths$gdal_translate <- binpaths$gdalwarp <- 
+    binpaths$gdalbuildvrt <- binpaths$gdaldem <- binpaths$gdal_polygonize <- NULL
   # set message method
   message_type <- ifelse(abort==TRUE, "error", "warning")
   
@@ -165,28 +168,28 @@ check_gdal <- function(abort = TRUE, gdal_path = NULL, force = FALSE, full_scan
   gdal_versions <- sort(gdal_versions, decreasing = TRUE)
   
   
-  ## Check requisite 2: OpenJPEG support
-  gdal_check_jp2 <- sapply(paths_gdalinfo, function(path) {
-    gdal_formats <- system(paste0(path," --formats"), intern = TRUE)
-    any(grepl("JP2OpenJPEG", gdal_formats))
-  })
-  if (!any(gdal_check_jp2)) {
-    print_message(
-      type=message_type,
-      "Your local GDAL installation does not support JPEG2000 (JP2OpenJPEG) format. ",
-      "Please install JP2OpenJPEG support and recompile GDAL.",
-      if (Sys.info()["sysname"] == "Windows") {paste0(
-        "\nUsing the OSGeo4W installer ",
-        "(http://download.osgeo.org/osgeo4w/osgeo4w-setup-x86",
-        if (Sys.info()["machine"]=="x86-64") {"_64"},".exe), ",
-        "choose the \"Advanced install\" and ",
-        "check the packages \"gdal-python\" and \"openjpeg\"."
-      )}
-    )
-    return(invisible(FALSE))
-  }
-  paths_gdalinfo <- paths_gdalinfo[gdal_check_jp2]
-  gdal_versions <- gdal_versions[gdal_check_jp2]
+  # ## Check requisite 2: OpenJPEG support
+  # gdal_check_jp2 <- sapply(paths_gdalinfo, function(path) {
+  #   gdal_formats <- system(paste0(path," --formats"), intern = TRUE)
+  #   any(grepl("JP2OpenJPEG", gdal_formats))
+  # })
+  # if (!any(gdal_check_jp2)) {
+  #   print_message(
+  #     type=message_type,
+  #     "Your local GDAL installation does not support JPEG2000 (JP2OpenJPEG) format. ",
+  #     "Please install JP2OpenJPEG support and recompile GDAL.",
+  #     if (Sys.info()["sysname"] == "Windows") {paste0(
+  #       "\nUsing the OSGeo4W installer ",
+  #       "(http://download.osgeo.org/osgeo4w/osgeo4w-setup-x86",
+  #       if (Sys.info()["machine"]=="x86-64") {"_64"},".exe), ",
+  #       "choose the \"Advanced install\" and ",
+  #       "check the packages \"gdal-python\" and \"openjpeg\"."
+  #     )}
+  #   )
+  #   return(invisible(FALSE))
+  # }
+  # paths_gdalinfo <- paths_gdalinfo[gdal_check_jp2]
+  # gdal_versions <- gdal_versions[gdal_check_jp2]
   
   
   ## Check requisite 3: in Windows and Mac, use only OSGeo version
@@ -209,16 +212,14 @@ check_gdal <- function(abort = TRUE, gdal_path = NULL, force = FALSE, full_scan
       print_message(
         type=message_type,
         if (Sys.info()["sysname"] == "Windows") {paste0(
-          "You do not have a local GDAL environment installed with OSGeo4W, ",
-          "which is a mandatory requirement since sen2r v. 1.1.0. ",
+          "You do not have a local GDAL environment installed with OSGeo4W. ",
           "\nPlease install GDAL using the OSGeo4W installer ",
           "(http://download.osgeo.org/osgeo4w/osgeo4w-setup-x86",
           if (Sys.info()["machine"]=="x86-64") {"_64"},".exe), ",
           "choosing the \"Advanced install\" and ",
-          "checking the packages \"gdal-python\" and \"openjpeg\"."
+          "checking the package \"gdal-python\"."
         )} else if (Sys.info()["sysname"] == "Darwin") {paste0(
-          "You do not have a local GDAL environment installed with OSGeo Homebrew, ",
-          "which is a mandatory requirement since sen2r v. 1.1.0. ",
+          "You do not have a local GDAL environment installed with OSGeo Homebrew. ",
           "\nPlease install GDAL from the OSGeo repository: ",
           "\n1. install Homebrew (https://brew.sh/);",
           "\n2. open a terminal and type ",
@@ -261,7 +262,7 @@ check_gdal <- function(abort = TRUE, gdal_path = NULL, force = FALSE, full_scan
         " (see the documentation at ",
         "https://sen2r.ranghetti.info/articles/installation#on-linux-systems ",
         "to see how to install the required dependency ",
-        "based on your Linux distribution.",
+        "based on your Linux distribution."
       )}
     )
     return(invisible(FALSE))
